@@ -71,9 +71,7 @@ TODO:
 
 #include "hp4200_lm9830.c"
 
-#define HP4200_CONFIG_FILE "HP4200.conf"
-
-#define DEFAULT_DEVICE "/dev/usb/scanner0"
+#define HP4200_CONFIG_FILE "hp4200.conf"
 
 /*--------------------------------------------------------------------------*/
 
@@ -2285,8 +2283,6 @@ sane_init (SANE_Int * version_code, SANE_Auth_Callback authorize)
 	static const char me[] = "sane_hp4200_init";
 	char dev_name[PATH_MAX];
 	FILE *fp;
-	int len;
-	SANE_Status status;
 
 	authorize = authorize;		/* keep gcc quiet */
 
@@ -2303,27 +2299,23 @@ sane_init (SANE_Int * version_code, SANE_Auth_Callback authorize)
 
 	fp = sanei_config_open (HP4200_CONFIG_FILE);
 	if (!fp) {
-		/* default to DEFAULT_DEVICE instead of insisting on config file */
 		DBG (DBG_error,
-			 "%s: configuration file not found, defaulting to %s.\n",
-			 me, DEFAULT_DEVICE);
-		status = add_device (DEFAULT_DEVICE, NULL);
-		if (status != SANE_STATUS_GOOD) {
-			DBG (DBG_error, "%s: failed to add device \"%s\"\n",
-				 me, dev_name);
-		}
+			 "%s: configuration file not found!\n", me);
+
+		return SANE_STATUS_INVAL;
 	}
 	else {
 		while (sanei_config_read (dev_name, sizeof (dev_name), fp)) {
 			if (dev_name[0] == '#')	/* ignore line comments */
 				continue;
 
-			len = strlen (dev_name);
-
-			if (!len)
+			if (strlen (dev_name) == 0)
 				continue;		/* ignore empty lines */
 
-			sanei_config_attach_matching_devices (dev_name, attach);
+			DBG (DBG_info, "%s: looking for devices matching %s\n",
+			     me, dev_name);
+
+			sanei_usb_attach_matching_devices (dev_name, attach);
 		}
 
 		fclose (fp);
